function PaHOF = computePaHOFonUV(u,v, gridconf, nAng, mags, len, step)
% PaHOF = computePaHOFonUV(u,v, gridconf, nAng, mags)
% Computes PaHOF descriptors given Optical Flow (u,v).
%
% Input:
%  - u,v: 3D matrices [nrows, ncols, nframes] with optical flow components
%  per location.
%  - gridconf: spatial grid. It can be either a 2D vector or a cell-array of
%  vectors. Each 2D vector is [XTiles, YTiles]. E.g. {[4 8] [2 4] [1 2]}
%  - nAng: number of bins for OF angle quantization. E.g. 8
%  - mags: magnitude intervals for quantization. E.g. [0.5 1.5 2.5]
%  - len: number of frames to accumulate. E.g. 20
%  - step: every 'step' frames a descriptor is computed. E.g. 2
%
% Output:
%  - PaHOF: matrix with descriptors [ndesc, ndims]
%
% Example
% =======
%  PaHOF = computePaHOFonUV(u,v, {[4 8] [2 4] [1 2]}, 8, [0.5 1.5 2.5]);
%
% See also computeAHOF, computeHOF
%   
% (c) MJMJ/2012
%

if iscell(gridconf)
   HOF = cell(1, length(gridconf));
   parfor pix = 1:length(gridconf)
      HOF{pix} = computeHOF(u, v, gridconf{pix}, nAng, mags);
   end % pix
else
   HOF = computeHOF(u, v, gridconf, nAng, mags);
end

%% Compute aHOF
nMags = length(mags)+1;
if iscell(HOF)
   aHOF = cell(1,length(HOF));
   aHOFun = cell(1,length(HOF));
   parfor pix = 1:length(HOF) % Run in parallel
      [aHOF{pix}, aHOFun{pix}] = computeAHOF(HOF{pix}, len, step, true, nMags);
   end % pix
else
   [aHOF, aHOFun] = computeAHOF(HOF, len, step, true, nMags);
end


%% Compute PaHOF
PaHOF = [];
if iscell(aHOF)
   for pix = 1:length(aHOF)
      PaHOF = [PaHOF, aHOF{pix}];
   end % pix
else
   PaHOF = aHOF;
end

